const connection = require('../model/connection');
const languageMessage = require('./languageMessage');
const sendmail = require('./MailerApi');
const resetmail = require('./ForgetMailer');
const BroadcastMail = require('./BroadcastMail');
const { hashPassword, getUserData } = require('./function');
const rs = require('randomstring');
const jwt = require('jsonwebtoken');

const FetchUser = async (request, response) => {
  try {
    const fetchDetails =
      'SELECT user_id, email, name, dob, mobile, image, address, bio, createtime FROM user_master WHERE delete_flag = 0 AND user_type = 1';

    connection.query(fetchDetails, (err, res) => {
      if (err) {
        return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
      }
      if (res.length <= 0) {
        return response.status(200).json({ success: false, msg: languageMessage.msgUserNotFound });
      }
      if (res.length > 0) {
        return response.status(200).json({ success: true, msg: languageMessage.msgDataFound, res });
      } else {
        return response.status(200).json({ success: false, msg: languageMessage.msgUserNotFound });
      }
    });
  } catch (error) {
    return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
  }
};

//fetchuserDate

const fetchuserDate = async (request, response) => {
  const { fromDate, toDate } = request.query;
  console.log(fromDate, toDate);
  if (!fromDate || !toDate) {
    return response.status(200).json({ success: false, msg: languageMessage.msg_empty_param });
  }
  try {
    // Ensure fromDate and toDate are properly formatted and in UTC to match MySQL datetime format
    // Example: '2024-06-01T00:00:00.000Z'

    const fetchDetails = `
      SELECT user_id, email, name, dob, mobile, image, address, bio, createtime 
      FROM user_master 
      WHERE delete_flag = 0 
        AND user_type = 1 
        AND createtime BETWEEN ? AND ?
    `;

    connection.query(fetchDetails, [fromDate, toDate], (err, res) => {
      if (err) {
        console.error('Error fetching user details:', err);
        return response.status(500).json({ success: false, msg: 'Internal server error' });
      }
      if (res.length <= 0) {
        return response.status(404).json({ success: false, msg: 'No users found' });
      }
      return response.status(200).json({ success: true, msg: 'User data found', data: res });
    });
  } catch (error) {
    console.error('Error in fetchuserDate endpoint:', error);
    return response.status(500).json({ success: false, msg: 'Internal server error' });
  }
};

const ViewUser = async (request, response) => {
  const { user_id } = request.params;

  if (!user_id) {
    return response.status(200).json({ success: false, msg: languageMessage.msg_empty_param, key: 'hey' });
  }
  var checkUser = 'SELECT user_id FROM user_master WHERE user_id = ? AND  delete_flag=0';

  connection.query(checkUser, [user_id], async (err, res) => {
    if (err) {
      return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
    }
    if (res.length <= 0) {
      return response.status(200).json({ success: false, msg: languageMessage.msgUserNotFound });
    }
    if (res[0].active_flag === 0) {
      return response.status(200).json({ success: false, msg: languageMessage.accountdeactivated });
    }
    if (res.length > 0) {
      var FetchDetails = 'SELECT user_id, name, image ,  email, mobile, dob, address, bio FROM user_master WHERE user_id = ?';

      connection.query(FetchDetails, [user_id], async (err, res) => {
        if (err) {
          return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
        } else {
          return response.status(200).json({ success: true, msg: languageMessage.msgDataFound, res });
        }
      });
    } else {
      return response.status(200).json({ success: false, msg: languageMessage.msgUserNotFound });
    }
  });
};

//Delete user

const DeleteUser = async (request, response) => {
  const data = request.body;

  const { user_id } = data;
  console.log(data);
  console.log(user_id);
  if (!user_id) {
    return response.status(200).json({ success: false, msg: languageMessage.msg_empty_param });
  }

  try {
    const checkUserQuery = 'SELECT * FROM user_master WHERE user_id = ? AND delete_flag = 0';
    connection.query(checkUserQuery, [user_id], async (err, res) => {
      if (err) {
        console.error('Error querying database:', err);
        return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
      }

      if (res.length === 0) {
        return response.status(200).json({ success: false, msg: languageMessage.msgUserNotFound });
      }

      const user = res[0];

      if (user.active_flag === 0) {
        return response.status(200).json({ success: false, msg: languageMessage.accountdeactivated });
      }

      const updateUserQuery = 'UPDATE user_master SET delete_flag = 1 WHERE user_id = ?';
      connection.query(updateUserQuery, [user_id], async (err) => {
        if (err) {
          console.error('Error updating user:', err);
          return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
        } else {
          return response.status(200).json({ success: true, msg: languageMessage.AccountDeleted });
        }
      });
    });
  } catch (error) {
    console.error('Caught exception:', error);
    return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
  }
};

//Fetch Delete user

const FetchDeleteUser = async (request, response) => {
  try {
    const fetchDetails =
      'SELECT user_id, email, name, dob, mobile, image, address, bio, createtime FROM user_master WHERE delete_flag = 1;';

    connection.query(fetchDetails, (err, res) => {
      if (err) {
        return response.status(500).json({ success: false, msg: languageMessage.internalServerError });
      } else {
        return response.status(200).json(res);
      }
    });
  } catch (error) {
    console.error('Caught exception:', error);
    return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
  }
};

//Fetch Post details

const FetchPostDetails = (request, response) => {
  const FetchPost =
    'SELECT user_id,post_id, title, video, thumbnail, category_id, type, wallpaper, createtime FROM post_master WHERE delete_flag=0';

  connection.query(FetchPost, (err, res) => {
    try {
      if (err) {
        return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
      }
      if (res.length <= 0) {
        return response.status(200).json({ success: false, msg: languageMessage.msgUserNotFound });
      }
      if (res[0].active_flag === 0) {
        return response.status(200).json({ success: false, msg: languageMessage.accountdeactivated });
      }

      const combinedData = [];
      let completedRequests = 0;

      res.map((row) => {
        const FetchData =
          'SELECT u.name as user_name, c.name as category_name FROM user_master u, category_master c WHERE u.user_id = ? AND c.category_id = ?';

        connection.query(FetchData, [row.user_id, row.category_id], (err, res1) => {
          try {
            if (err) {
              return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
            }

            if (res1.length > 0) {
              combinedData.push({
                post: row,
                userDetails: res1[0]
              });
            }

            completedRequests++;

            // Check if all queries are completed
            if (completedRequests === res.length) {
              if (combinedData.length > 0) {
                return response.status(200).json({ success: true, msg: languageMessage.msgDataFound, data: combinedData });
              } else {
                return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
              }
            }
          } catch (error) {
            return response.status(200).json({ success: false, msg: error.message, error: error });
          }
        });
      });
    } catch (error) {
      return response.status(200).json({ success: false, msg: error.message, error: error });
    }
  });
};

// View Post

const ViewPost = async (request, response) => {
  const { post_id } = request.params;
  // console.log(post_id);

  if (!post_id) {
    return response.status(200).json({ success: false, msg: languageMessage.msg_empty_param, key: 'post' });
  }

  const combinedData = [];
  var completedRequests = 0;

  var checkpost =
    'SELECT post_id, user_id,post_id, title, video, thumbnail, category_id, type, wallpaper, createtime  FROM post_master WHERE post_id =? AND delete_flag = 0';

  connection.query(checkpost, [post_id], async (err, res) => {
    if (err) {
      return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
    }
    if (res.length <= 0) {
      return response.status(200).json({ success: false, msg: languageMessage.NoPostFound });
    }
    if (res[0].active_flag === 0) {
      return response.status(200).json({ success: false, msg: languageMessage.accountdeactivated });
    }
    if (res.length > 0) {
      var FetchDetail =
        'SELECT u.name as user_name, c.name as category_name FROM user_master u, category_master c WHERE u.user_id = ? AND c.category_id = ?';

      connection.query(FetchDetail, [res[0].user_id, res[0].category_id], (err, res1) => {
        try {
          if (err) {
            return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
          }

          if (res1.length > 0) {
            combinedData.push({
              post: res[0],
              userDetails: res1[0]
            });
          }

          completedRequests++;

          // Check if all queries are completed
          if (completedRequests === res.length) {
            if (combinedData.length > 0) {
              return response.status(200).json({ success: true, msg: languageMessage.msgDataFound, data: combinedData });
            } else {
              return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
            }
          }
        } catch (error) {
          return response.status(200).json({ success: false, msg: error.message, error: error });
        }
      });
    } else {
      return response.status(200).json({ success: false, msg: languageMessage.NoPostFound });
    }
  });
};

//Delete Post

const DeletePost = async (request, response) => {
  const Data = request.body;
  const { post_id } = Data;
  console.log(post_id);
  if (!post_id) {
    return response.status(200).json({ success: false, msg: languageMessage.msg_empty_param, key: 'post id' });
  }

  var checkPost = 'SELECT post_id FROM post_master WHERE post_id = ? AND delete_flag = 0';

  connection.query(checkPost, [post_id], async (err, res) => {
    if (err) {
      return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
    }
    if (res.length <= 0) {
      return response.status(200).json({ success: false, msg: languageMessage.msgUserNotFound, res: [] });
    }
    if (res[0].active_flag === 0) {
      return response.status(200).json({ success: false, msg: languageMessage.accountdeactivated });
    }
    if (res.length > 0) {
      var DeletePost = 'UPDATE post_master SET delete_flag = 1 WHERE post_id = ?';

      connection.query(DeletePost, [post_id], async (err) => {
        if (err) {
          return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
        } else {
          return response.status(200).json({ success: true, msg: languageMessage.PostDeleted });
        }
      });
    }
  });
};

//Fetch Category

const FetchCategory = async (request, response) => {
  var FetchCategory = 'SELECT category_id, name, createtime FROM category_master WHERE delete_flag = 0';

  connection.query(FetchCategory, async (err, res) => {
    if (err) {
      return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
    }
    if (res.length <= 0) {
      return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
    }
    if (res.length > 0) {
      return response.status(200).json({ success: true, msg: languageMessage.msgDataFound, res });
    }
  });
};

// Add Category
const AddCategory = async (request, response) => {
  const { category_name } = request.body;

  if (!category_name) {
    return response.status(200).json({ success: false, msg: languageMessage.msg_empty_param });
  }

  try {
    const CheckCategory = 'SELECT name FROM category_master WHERE name = ? AND delete_flag = 0';
    connection.query(CheckCategory, [category_name], (err, res) => {
      if (err) {
        return response.status(200).json({ success: false, msg: languageMessage.internalServerError, error: err });
      }

      if (res.length > 0) {
        return response.status(200).json({ success: false, msg: languageMessage.CategoryAleradyExist, key: 'categoryExists' });
      }

      const Insert = 'INSERT INTO category_master(name, createtime) VALUES (?, NOW())';
      connection.query(Insert, [category_name], (err, insertRes) => {
        if (err) {
          return response.status(200).json({ success: false, msg: languageMessage.internalServerError, error: err });
        } else {
          const newCategory = {
            category_id: insertRes.insertId,
            name: category_name,
            createtime: new Date().toISOString()
          };
          return response.status(200).json({ success: true, msg: languageMessage.CategoryAdded, newCategory });
        }
      });
    });
  } catch (error) {
    return response.status(200).json({ success: false, msg: languageMessage.internalServerError, error });
  }
};

//Delete Category

const DeleteCategory = async (request, response) => {
  const { category_id } = request.body;
  console.log(category_id);

  if (!category_id) {
    return response.status(200).json({ success: false, msg: languageMessage.msg_empty_param });
  }

  try {
    var Check = 'SELECT category_id FROM category_master WHERE delete_flag = 0';
    connection.query(Check, async (err, res) => {
      if (err) {
        return response.status(200).json({ success: false, msg: languageMessage.internalServerError, error: err });
      }
      if (res.length <= 0) {
        return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
      }
      if (res.length > 0) {
        var Delete = 'UPDATE category_master SET delete_flag = 1 WHERE category_id = ?';

        connection.query(Delete, [category_id], async (err) => {
          if (err) {
            return response.status(200).json({ success: false, msg: languageMessage.internalServerError, error: err });
          } else {
            return response.status(200).json({ success: true, msg: languageMessage.DeleteCategory });
          }
        });
      } else {
        return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
      }
    });
  } catch (err) {
    return response.status(200).json({ success: false, msg: languageMessage.internalServerError, err });
  }
};

//Category Update

const UpdateCategory = async (request, response) => {
  const { category_id, category_name } = request.body;

  if (!category_id) {
    return response.status(200).json({ success: false, msg: languageMessage.msg_empty_param });
  }

  try {
    var CheckCategory = 'SELECT category_id FROM category_master WHERE delete_flag = 0';
    connection.query(CheckCategory, [category_id], async (err, res) => {
      if (err) {
        return response.status(200).json({ success: false, msg: languageMessage.internalServerError, error: err });
      }
      if (res.length <= 0) {
        return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
      }
      if (res.length > 0) {
        var check = 'SELECT name FROM category_master WHERE name = ? AND delete_flag = 0';
        connection.query(check, [category_name], async (err, res1) => {
          if (err) {
            return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
          }
          if (res1.length > 0) {
            return response.status(200).json({ success: false, msg: languageMessage.CategoryAleradyExist, key: 'categoryExists' });
          }
          if (res1.length <= 0) {
            var UpdateCategory = 'UPDATE category_master SET name = ? WHERE category_id = ?';
            connection.query(UpdateCategory, [category_name, category_id], async (err) => {
              if (err) {
                return response.status(200).json({ success: false, msg: languageMessage.internalServerError, error: err });
              } else {
                return response.status(200).json({ success: true, msg: languageMessage.CategoryUpdated });
              }
            });
          } else {
            return response.status(200).json({ success: false, msg: languageMessage.CategoryAleradyExist });
          }
        });
      } else {
        return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
      }
    });
  } catch (error) {
    return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
  }
};

// Fetch All Subscriptions

const FetchAllSubscriptions = async (request, response) => {
  try {
    var Fetch =
      'SELECT subscription_id, number_off_day, amount, subscription_type, description, createtime FROM subscription_master WHERE delete_flag = 0';

    connection.query(Fetch, async (err, res) => {
      if (err) {
        return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
      }
      if (res.length <= 0) {
        return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound, res: [] });
      }
      if (res.length > 0) {
        return response.status(200).json({ success: true, msg: languageMessage.msgDataFound, res });
      } else {
        return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
      }
    });
  } catch (error) {
    return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
  }
};

// Add Subscription
const AddSubscription = async (request, response) => {
  const { number_off_day, amount, subscription_type, description } = request.body;
  console.log(number_off_day, amount, subscription_type, description);
  if (!number_off_day || !amount || !subscription_type || !description) {
    return response.status(200).json({
      success: false,
      msg: languageMessage.msg_empty_param,
      key: !number_off_day ? 'number of days' : !amount ? 'amount' : !subscription_type ? 'subscription type' : 'description'
    });
  }

  try {
    var checkSubscription =
      'SELECT number_off_day, amount FROM subscription_master WHERE number_off_day = ? AND amount = ? AND delete_flag = 0';

    connection.query(checkSubscription, [number_off_day, amount], async (err, res) => {
      if (err) {
        return response.status(200).json({ success: false, msg: languageMessage.internalServerError, error: err });
      }
      if (res.length > 0) {
        return response.status(200).json({ success: false, msg: languageMessage.SubscriptionExists, key: 'subscrptionExits' });
      }
      if (res.length <= 0) {
        var Insert =
          'INSERT INTO subscription_master(number_off_day, amount, subscription_type, description, createtime) VALUES(?, ?, ?, ?, NOW())';

        connection.query(Insert, [number_off_day, amount, subscription_type, description], async (err, res1) => {
          if (err) {
            return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
          } else {
            const newSubscription = {
              subscription_id: res1.insertId,
              number_off_day: number_off_day,
              amount: amount,
              subscription_type: subscription_type,
              description: description,
              createtime: new Date().toISOString()
            };
            return response.status(200).json({ success: true, msg: languageMessage.SubscriptionAdded, newSubscription });
          }
        });
      }
    });
  } catch (error) {
    return response.status(200).json({ success: false, msg: languageMessage.internalServerError, error: error });
  }
};

// Delete Subscription
const DeleteSubscription = async (request, response) => {
  const { subscription_id } = request.body;
  if (!subscription_id) {
    return response.status(200).json({ success: false, msg: languageMessage.msg_empty_param, key: 'subscription_id' });
  }

  try {
    var CheckSubscription = 'SELECT subscription_id FROM subscription_master WHERE subscription_id = ? AND delete_flag = 0';
    connection.query(CheckSubscription, [subscription_id], async (err, res) => {
      if (err) {
        return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
      }
      if (res.length <= 0) {
        return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
      }
      if (res.length > 0) {
        var Delete = 'UPDATE subscription_master SET delete_flag = 1 WHERE subscription_id = ?';
        connection.query(Delete, [subscription_id], async (err) => {
          if (err) {
            return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
          } else {
            return response.status(200).json({ success: true, msg: languageMessage.SubscriptionDeleted });
          }
        });
      }
    });
  } catch (error) {
    return response.status(200).json({ success: false, msg: languageMessage.internalServerError, error: error });
  }
};

//Edit Subscription
const EditSubscription = async (request, response) => {
  const { subscription_id, number_off_day, amount, subscription_type, description } = request.body;

  if (!subscription_id || !number_off_day || !amount || !subscription_type || !description) {
    return response.status(200).json({
      success: false,
      msg: languageMessage.msg_empty_param,
      key: !subscription_id
        ? 'Subscription Id'
        : !number_off_day
        ? 'Number of days'
        : !amount
        ? 'amount'
        : !subscription_type
        ? 'subscription type'
        : 'description'
    });
  }

  try {
    const CheckSubscription = 'SELECT subscription_id FROM subscription_master WHERE subscription_id = ? AND delete_flag = 0';
    connection.query(CheckSubscription, [subscription_id], (err, res) => {
      if (err) {
        return response.status(200).json({ success: false, msg: languageMessage.internalServerError, error: err });
      }
      if (res.length <= 0) {
        return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
      }

      const check = 'SELECT number_off_day, amount FROM subscription_master WHERE number_off_day = ? AND amount = ? AND delete_flag = 0';
      connection.query(check, [number_off_day, amount], (err, res1) => {
        if (err) {
          return response.status(200).json({ success: false, msg: languageMessage.internalServerError, error: err });
        }
        if (res1.length > 0) {
          return response.status(200).json({ success: false, msg: languageMessage.SubscriptionExists, key: 'SubscriptionExists' });
        }
        if (res1.length <= 0) {
          const UpdateSubscription =
            'UPDATE subscription_master SET number_off_day = ?, amount = ?, subscription_type = ?, description = ? WHERE subscription_id = ?';
          connection.query(UpdateSubscription, [number_off_day, amount, subscription_type, description, subscription_id], (err) => {
            if (err) {
              return response.status(200).json({ success: false, msg: languageMessage.internalServerError, error: err });
            } else {
              return response.status(200).json({ success: true, msg: languageMessage.SubscriptionUpdated });
            }
          });
        } else {
          return response.status(200).json({ success: false, msg: languageMessage.SubscriptionExists, key: 'SubscriptionExists' });
        }
      });
    });
  } catch (error) {
    return response.status(200).json({ success: false, msg: languageMessage.internalServerError, error });
  }
};

// Get All Announcements

const GetAllAnnouncements = async (request, response) => {
  try {
    const Fetch = 'SELECT announcement_id, user_id, announcement, createtime FROM announcement_master WHERE delete_flag = 0';
    connection.query(Fetch, async (err, res) => {
      if (err) {
        return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
      }
      if (res.length <= 0) {
        return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
      }

      const MultiData = [];
      let completedRequests = 0;

      for (let i = 0; i < res.length; i++) {
        const FetchUserName = 'SELECT name FROM user_master WHERE user_id = ? AND delete_flag = 0';
        connection.query(FetchUserName, [res[i].user_id], (error, res1) => {
          if (error) {
            return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
          }
          if (res1.length > 0) {
            MultiData.push({
              allData: res[i],
              userDetails: res1[0]
            });
          }
          completedRequests++;

          if (completedRequests === res.length) {
            if (MultiData.length > 0) {
              return response.status(200).json({ success: true, msg: languageMessage.msgDataFound, data: MultiData });
            } else {
              return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
            }
          }
        });
      }
    });
  } catch (error) {
    return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
  }
};

// Delete Announcements

const DeleteAnnouncements = async (request, response) => {
  const { announcement_id } = request.body;

  if (!announcement_id) {
    return response.status(200).json({ success: false, msg: languageMessage.msg_empty_param, key: 'announcement' });
  }
  try {
    var Check = 'SELECT announcement_id FROM announcement_master WHERE announcement_id = ? AND delete_flag = 0';
    connection.query(Check, [announcement_id], async (err, res) => {
      if (err) {
        return response.status(200).json({ success: false, msg: languageMessage.internalServerError, error: err });
      }
      if (res.length <= 0) {
        return response.status(200).json({ success: false, mgs: languageMessage.msgDataNotFound });
      }
      if (res.length > 0) {
        var Delete = 'UPDATE announcement_master SET delete_flag = 1 WHERE announcement_id = ?;';
        connection.query(Delete, [announcement_id], async (err) => {
          if (err) {
            return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
          } else {
            return response.status(200).json({ success: true, msg: languageMessage.AnnouncementDeleted });
          }
        });
      } else {
        return response.status(200).json({ success: false, mgs: languageMessage.msgDataNotFound });
      }
    });
  } catch (error) {
    return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
  }
};

//Fetch Subscribed Users
const FetchSubscribedUsers = async (request, response) => {
  try {
    var fetch =
      'SELECT user_id, subscription_id, subscription_type, description, amount, status, start_date, end_date, createtime FROM user_subscription_master WHERE delete_flag = 0';
    connection.query(fetch, async (err, res) => {
      if (err) {
        return response.status(200).json({ success: false, msg: languageMessage.internalServerError, error: err });
      }
      if (res.length <= 0) {
        return response.status(200).json({ success: false, msg: languageMessage.msgUserNotFound });
      }
      if (res.length > 0) {
        // console.log(res);
        const MultiData = [];
        let completedRequests = 0;

        for (let i = 0; i < res.length; i++) {
          const FetchUserName = 'SELECT name FROM user_master WHERE user_id = ? AND delete_flag = 0';
          connection.query(FetchUserName, [res[i].user_id], (error, res1) => {
            if (error) {
              return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
            }
            if (res1.length > 0) {
              MultiData.push({
                allData: res[i],
                userDetails: res1[0]
              });
            }
            completedRequests++;

            if (completedRequests === res.length) {
              if (MultiData.length > 0) {
                return response.status(200).json({ success: true, msg: languageMessage.msgDataFound, data: MultiData });
              } else {
                return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
              }
            }
          });
        }
      } else {
        return response.status(200).json({ success: false, msg: languageMessage.msgUserNotFound });
      }
    });
  } catch (error) {
    return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
  }
};

// Fetch reported Conentent
const FetchReportedContent = async (request, response) => {
  try {
    var Fetch =
      'SELECT report_id, user_id, other_user_id, report_type, reason, report_status, createtime FROM report_master WHERE delete_flag = 0';
    connection.query(Fetch, async (err, res) => {
      if (err) {
        return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
      }
      if (res.length <= 0) {
        return response.status(200).json({ success: false, msg: languageMessage.msgUserNotFound });
      }
      if (res.length > 0) {
        const MultiData = [];
        let completedRequests = 0;

        for (let i = 0; i < res.length; i++) {
          const FetchUserName = 'SELECT name FROM user_master WHERE user_id = ? AND delete_flag = 0';
          connection.query(FetchUserName, [res[i].user_id], (error, res1) => {
            if (error) {
              return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
            }
            if (res1.length > 0) {
              const userName = res1[0].name;

              const FetchOtherUserName = 'SELECT name FROM user_master WHERE user_id = ? AND delete_flag = 0';
              connection.query(FetchOtherUserName, [res[i].other_user_id], (error, res2) => {
                if (error) {
                  return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
                }
                if (res2.length > 0) {
                  const otherUserName = res2[0].name;
                  MultiData.push({
                    allData: res[i],
                    userDetails: { userName, otherUserName }
                  });
                }
                completedRequests++;

                if (completedRequests === res.length) {
                  if (MultiData.length > 0) {
                    return response.status(200).json({ success: true, msg: languageMessage.msgDataFound, data: MultiData });
                  } else {
                    return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
                  }
                }
              });
            } else {
              completedRequests++;

              if (completedRequests === res.length) {
                if (MultiData.length > 0) {
                  return response.status(200).json({ success: true, msg: languageMessage.msgDataFound, data: MultiData });
                } else {
                  return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
                }
              }
            }
          });
        }
      } else {
        return response.status(200).json({ success: false, msg: languageMessage.msgUserNotFound });
      }
    });
  } catch (error) {
    return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
  }
};

// Edit Reported Content
const EditReportedContent = async (request, response) => {
  const { report_id } = request.body;

  if (!report_id) {
    return response.status(200).json({ success: false, msg: languageMessage.msg_empty_param });
  }

  try {
    var check = 'SELECT report_id FROM report_master WHERE report_id = ? AND delete_flag = 0';
    connection.query(check, [report_id], async (err, res) => {
      if (err) {
        return response.status(200).json({ success: false, msg: languageMessage });
      }
      if (res.length <= 0) {
        return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
      }
      if (res.length > 0) {
        var resolved = 'UPDATE report_master SET report_status = 1 WHERE report_id = ?';
        connection.query(resolved, [report_id], async (err) => {
          if (err) {
            return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
          } else {
            return response.status(200).json({ success: true, msg: languageMessage.Resolved });
          }
        });
      } else {
        return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
      }
    });
  } catch (error) {
    return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
  }
};

// Fetch About Content
const fetchaboutcontent = async (request, response) => {
  const { contentType } = request.query;
  // console.log(contentType);
  if (!contentType) {
    return response.status(200).json({ success: false, msg: languageMessage.msg_empty_param });
  }

  try {
    var fetch = 'SELECT content FROM content_master WHERE content_type = ? AND delete_flag = 0';
    connection.query(fetch, [contentType], async (err, res) => {
      if (err) {
        return response.status(20).json({ success: false, smg: languageMessage.internalServerError });
      }
      if (res.length <= 0) {
        return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
      }
      if (res.length > 0) {
        return response.status(200).json({ success: true, msg: languageMessage.msgDataFound, res });
      } else {
        return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
      }
    });
  } catch (error) {
    return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
  }
};

//Update Content

const updateContent = async (request, response) => {
  const contentType = request.body.contentType;
  const content = request.body.content;

  console.log('Received contentType:', contentType);
  console.log('Received content:', content);

  // Check if contentType or content is missing
  if (contentType === undefined || content === undefined) {
    console.log('Missing parameters');
    return response.status(200).json({ success: false, msg: languageMessage.msg_empty_param, key: 'none' });
  }

  try {
    const check = 'SELECT content_type FROM content_master WHERE content_type = ? AND delete_flag = 0';

    connection.query(check, [contentType], async (err, res) => {
      if (err) {
        console.error('Error executing SELECT query:', err);
        return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
      }

      console.log('SELECT query result:', res);

      if (res.length <= 0) {
        return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
      }

      const updateQuery = 'UPDATE content_master SET content = ? WHERE content_type = ?';

      connection.query(updateQuery, [content, contentType], async (err, res1) => {
        if (err) {
          console.error('Error executing UPDATE query:', err);
          return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
        }

        console.log('UPDATE query result:', res1);

        if (res1.affectedRows > 0) {
          return response.status(200).json({ success: true, msg: languageMessage.ContentUpdated });
        } else {
          return response.status(200).json({ success: false, msg: 'No rows affected' });
        }
      });
    });
  } catch (error) {
    console.error('Error updating content:', error);
    response.status(200).json({ success: false, msg: languageMessage.internalServerError });
  }
};

//Fetch Contact us
const FetchContactUs = async (request, response) => {
  try {
    var fetch =
      'SELECT contact_id, name, email, message, user_type, file, status, subject, replied_date_time FROM contact_us_master WHERE delete_flag = 0';
    connection.query(fetch, async (err, res) => {
      if (err) {
        return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
      }
      if (res.length <= 0) {
        return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
      }
      if (res.length > 0) {
        return response.status(200).json({ success: true, msg: languageMessage.msgDataFound, res });
      } else {
        return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
      }
    });
  } catch (error) {
    return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
  }
};

const SendMail = async (request, response) => {
  const { email, message } = request.body;

  if (!email || !message) {
    return response.status(200).json({ success: false, msg: languageMessage.msg_empty_param });
  }

  try {
    // Example logic to check if email exists in database
    const checkQuery = 'SELECT email FROM contact_us_master WHERE email = ? AND delete_flag = 0';
    connection.query(checkQuery, [email], async (err, res) => {
      if (err) {
        return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
      }

      if (res.length <= 0) {
        return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
      }
      if (res.length > 0) {
        // Convert message to a string if it's an object
        const formattedMessage = typeof message === 'object' ? JSON.stringify(message) : message;
        sendmail(email, formattedMessage);
        return response.status(200).json({ success: true, msg: languageMessage.EmailSent });
      } else {
        return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
      }
    });
  } catch (error) {
    console.error('Error:', error);
    return response.status(200).json({ success: false, msg: 'Internal server error' });
  }
};

// Update Contact status

const updateStatus = async (request, response) => {
  const { contact_id } = request.body;
  if (!contact_id) {
    return response.status(200).json({ success: false, msg: languageMessage.msg_empty_param });
  }
  console.log(contact_id);
  try {
    var check = 'SELECT contact_id FROM contact_us_master WHERE contact_id = ? AND delete_flag = 0';
    connection.query(check, [contact_id], async (err, res) => {
      if (err) {
        return response.status(200).json({ success: false, msg: languageMessage.internalServerError, error: err });
      }
      if (res.length <= 0) {
        return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
      }
      if (res.length > 0) {
        var update = 'UPDATE contact_us_master SET status = 1 , replied_date_time = NOW() WHERE contact_id =? ';
        connection.query(update, [contact_id], async (err) => {
          if (err) {
            return response.status(200).json({ success: false, msg: languageMessage.internalServerError, error: err });
          } else {
            return response.status(200).json({ success: true, msg: languageMessage.RepliedSuccessfully });
          }
        });
      } else {
        return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
      }
    });
  } catch (error) {
    return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
  }
};

// Broadcast message to All users
const BroadcastAll = async (request, response) => {
  const { title, message } = request.body;
  if (!title || !message) {
    return response.status(200).json({ success: false, msg: languageMessage.msg_empty_param });
  }

  try {
    var fetch = 'SELECT email FROM user_master WHERE delete_flag = 0 AND profile_complete = 1';
    connection.query(fetch, async (err, res) => {
      if (err) {
        return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
      }
      if (res.length <= 0) {
        return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
      }

      let completedEmails = 0;
      for (let i = 0; i < res.length; i++) {
        const UserEmail = res[i].email;
        console.log(UserEmail);
        // Assuming BroadcastMail is an asynchronous function, use await
        await BroadcastMail(UserEmail, title, message);
        completedEmails++;

        if (completedEmails === res.length) {
          return response.status(200).json({ success: true, msg: languageMessage.BrodcastSent });
        }
      }
    });
  } catch (error) {
    return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
  }
};

//Users

const Users = async (request, response) => {
  var fetch = 'SELECT user_id, name FROM user_master WHERE delete_flag = 0';
  connection.query(fetch, async (err, res) => {
    if (err) {
      return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
    }
    if (res.length <= 0) {
      return response.status(200).json({ success: false, msg: languageMessage.msgUserNotFound });
    }
    if (res.length > 0) {
      return response.status(200).json({ success: true, msg: languageMessage.msgDataFound, res });
    } else {
      return response.status(200).json({ success: false, msg: languageMessage.msgUserNotFound });
    }
  });
};

// FetchSubscribedUsersByDate

const FetchSubscribedUsersByDate = async (request, response) => {
  const { fromDate, toDate } = request.query;
  console.log(fromDate, toDate);
  if (!fromDate || !toDate) {
    return response.status(200).json({ success: false, msg: languageMessage.msg_empty_param });
  }
  try {
    var fetch =
      'SELECT user_id, subscription_id, subscription_type, description, amount, status, start_date, end_date, createtime FROM user_subscription_master WHERE delete_flag = 0 AND createtime BETWEEN ? AND ?';
    connection.query(fetch, [fromDate, toDate], async (err, res) => {
      if (err) {
        return response.status(200).json({ success: false, msg: languageMessage.internalServerError, error: err });
      }
      if (res.length <= 0) {
        return response.status(200).json({ success: false, msg: languageMessage.msgUserNotFound });
      }
      if (res.length > 0) {
        // console.log(res);
        const MultiData = [];
        let completedRequests = 0;

        for (let i = 0; i < res.length; i++) {
          const FetchUserName = 'SELECT name FROM user_master WHERE user_id = ? AND delete_flag = 0';
          connection.query(FetchUserName, [res[i].user_id], (error, res1) => {
            if (error) {
              return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
            }
            if (res1.length > 0) {
              MultiData.push({
                allData: res[i],
                userDetails: res1[0]
              });
            }
            completedRequests++;

            if (completedRequests === res.length) {
              if (MultiData.length > 0) {
                return response.status(200).json({ success: true, msg: languageMessage.msgDataFound, data: MultiData });
              } else {
                return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
              }
            }
          });
        }
      } else {
        return response.status(200).json({ success: false, msg: languageMessage.msgUserNotFound });
      }
    });
  } catch (error) {
    return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
  }
};

//AdminData

const AdminData = async (request, response) => {
  try {
    var fetch = 'SELECT name, email, mobile, image FROM user_master WHERE user_type = 0 AND delete_flag = 0';
    connection.query(fetch, async (err, res) => {
      if (err) {
        return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
      }
      if (res.length <= 0) {
        return response.status(200).json({ success: false, msg: languageMessage.msgUserNotFound });
      }
      if (res.length > 0) {
        return response.status(200).json({ success: true, msg: languageMessage.msgDataFound, res });
      } else {
        return response.status(200).json({ success: false, msg: languageMessage.msgUserNotFound });
      }
    });
  } catch (error) {
    return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
  }
};

// Edit Admin Profile

const UpdateAdminProfile = async (req, res) => {
  const { name, email, mobile } = req.body;
  const image = req.file ? req.file.filename : null;

  if (!name || !email || !mobile) {
    return res.status(200).json({ success: false, msg: 'Missing required parameters.' });
  }

  try {
    const updateQuery = 'UPDATE user_master SET name = ?, email = ?, mobile = ?, image = ? WHERE user_type = 0 AND delete_flag = 0';
    connection.query(updateQuery, [name, email, mobile, image], (err, result) => {
      if (err) {
        console.error('Error updating profile:', err);
        return res.status(200).json({ success: false, msg: languageMessage.internalServerError });
      }

      if (result.affectedRows > 0) {
        return res.status(200).json({ success: true, msg: languageMessage.AdminProfileUpdated });
      } else {
        return res.status(200).json({ success: false, msg: languageMessage.internalServerError });
      }
    });
  } catch (error) {
    console.error('Exception during profile update:', error);
    return res.status(200).json({ success: false, msg: 'Internal server error.' });
  }
};

const UpdateAdminPassword = async (request, response) => {
  const { oldPassword, newPassword } = request.body;
  // console.log(oldPassword);
  // console.log(newPassword);
  try {
    if (!oldPassword) {
      return response.status(200).json({ success: false, msg: languageMessage.msg_empty_param, key: 'old_password' });
    }
    if (!newPassword) {
      return response.status(200).json({ success: false, msg: languageMessage.msg_empty_param, key: 'new_password' });
    }

    var sql = 'SELECT user_id FROM user_master WHERE user_type = 0 and delete_flag = 0';

    connection.query(sql, async (err, info) => {
      if (err) {
        return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
      }

      if (info.length <= 0) {
        return response.status(200).json({ success: false, msg: languageMessage.msgUserNotFound });
      }

      if (info[0].active_flag === 0) {
        return response.status(200).json({ success: false, msg: languageMessage.accountdeactivated, active_status: 0 });
      }
      console.log(info[0].user_id);
      var sqlforget = 'select password from user_master where user_id = ?';

      connection.query(sqlforget, [info[0].user_id], async (err, data) => {
        if (err) {
          return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
        } else {
          if (data.length <= 0) {
            return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
          }

          var password = data[0].password;

          console.log(password);
          const old_password_hash = await hashPassword(oldPassword);
          // console.log('this is mine ', old_password_hash);
          // console.log('db pass', password);
          if (password === old_password_hash) {
            const new_pass = await hashPassword(newPassword);

            var updateSql = 'UPDATE user_master SET password=?, updatetime = NOW() WHERE user_id = ? AND delete_flag = 0';

            connection.query(updateSql, [new_pass, info[0].user_id], (err) => {
              if (err) {
                return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
              } else {
                return response.status(200).json({ success: true, msg: languageMessage.PasswordUpdatedSuccessfully, key: 'success' });
              }
            });
          } else {
            return response.status(200).json({ success: false, msg: languageMessage.newOldPassword, key: 'failure' });
          }
        }
      });
    });
  } catch (error) {
    console.error('Error:', error);

    return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
  }
};

// fetch Subscription By Id
const fetchSubscriptionById = async (request, response) => {
  const { user_id } = request.params;

  if (!user_id) {
    return response.status(200).json({ success: false, msg: languageMessage.msg_empty_param });
  }

  try {
    // Check if user_id exists in user_subscription_master
    const checkQuery = 'SELECT user_id FROM user_subscription_master WHERE user_id = ? AND delete_flag = 0';
    connection.query(checkQuery, [user_id], async (err, checkRes) => {
      if (err) {
        return response.status(200).json({ success: false, msg: languageMessage.internalServerError, error: err });
      }

      if (checkRes.length === 0) {
        return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
      }

      // Fetch subscription details including number_of_days
      const fetchQuery = `
        SELECT 
          usm.subscription_id, 
          usm.amount, 
          usm.subscription_type, 
          usm.status, 
          usm.description, 
          usm.start_date, 
          usm.end_date, 
          sm.number_off_day 
        FROM 
          user_subscription_master usm
        JOIN 
          subscription_master sm ON usm.subscription_id = sm.subscription_id
        WHERE 
          usm.user_id = ? AND usm.delete_flag = 0
      `;

      connection.query(fetchQuery, [user_id], async (err, fetchRes) => {
        if (err) {
          return response.status(200).json({ success: false, msg: languageMessage.internalServerError, error: err });
        }

        if (fetchRes.length === 0) {
          return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
        }

        return response.status(200).json({ success: true, msg: languageMessage.msgDataFound, data: fetchRes });
      });
    });
  } catch (error) {
    console.error('Error in fetchSubscriptionById:', error);
    return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
  }
};

//fetch post details By Id
const fetchpostdetailsById = async (request, response) => {
  const { user_id } = request.params;

  if (!user_id) {
    return response.status(200).json({ success: false, msg: languageMessage.msg_empty_param });
  }

  try {
    // Check if user_id exists in post_master
    const checkQuery = 'SELECT user_id FROM post_master WHERE user_id = ? AND delete_flag = 0';
    connection.query(checkQuery, [user_id], async (err, checkRes) => {
      if (err) {
        console.error('Error checking post_master:', err);
        return response.status(200).json({ success: false, msg: languageMessage.internalServerError, error: err });
      }

      if (checkRes.length === 0) {
        return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
      }

      // Fetch post details including category information
      const fetchQuery = `
        SELECT 
          usm.user_id, 
          usm.title, 
          usm.video, 
          usm.thumbnail, 
          usm.category_id, 
          usm.type, 
          usm.wallpaper, 
          usm.createtime,
          cm.name
        FROM 
          post_master usm
        JOIN 
          category_master cm ON usm.category_id = cm.category_id
        WHERE 
          usm.user_id = ? AND usm.delete_flag = 0
      `;

      connection.query(fetchQuery, [user_id], async (err, fetchRes) => {
        if (err) {
          console.error('Error fetching post details:', err);
          return response.status(200).json({ success: false, msg: languageMessage.internalServerError, error: err });
        }

        if (fetchRes.length === 0) {
          return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
        }

        return response.status(200).json({ success: true, msg: languageMessage.msgDataFound, data: fetchRes });
      });
    });
  } catch (error) {
    console.error('Error in fetchpostdetailsById:', error);
    return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
  }
};

//get Announcements By Id
const getAnnouncementsById = async (request, response) => {
  const { user_id } = request.params;

  if (!user_id) {
    return response.status(200).json({ success: false, msg: languageMessage.msg_empty_param });
  }

  try {
    // Check if user_id exists in post_master
    const checkQuery = 'SELECT user_id FROM announcement_master WHERE user_id = ? AND delete_flag = 0';
    connection.query(checkQuery, [user_id], async (err, checkRes) => {
      if (err) {
        console.error('Error checking post_master:', err);
        return response.status(200).json({ success: false, msg: languageMessage.internalServerError, error: err });
      }

      if (checkRes.length === 0) {
        return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
      }

      // Fetch post details including category information
      const fetchQuery = 'SELECT announcement , createtime FROM announcement_master WHERE user_id = ? AND delete_flag=0';

      connection.query(fetchQuery, [user_id], async (err, fetchRes) => {
        if (err) {
          console.error('Error fetching post details:', err);
          return response.status(200).json({ success: false, msg: languageMessage.internalServerError, error: err });
        }

        if (fetchRes.length === 0) {
          return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
        }

        return response.status(200).json({ success: true, msg: languageMessage.msgDataFound, data: fetchRes });
      });
    });
  } catch (error) {
    console.error('Error in fetchpostdetailsById:', error);
    return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
  }
};

// User Count for analytics report
const UserCount = async (request, response) => {
  try {
    var fetch =
      'SELECT YEAR(createtime) AS year, MONTH(createtime) AS month, COUNT(*) AS user_count FROM user_master WHERE user_type = 1 GROUP BY YEAR(createtime), MONTH(createtime) ORDER BY year ASC, month ASC';

    connection.query(fetch, async (err, res) => {
      if (err) {
        return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
      } else {
        return response.status(200).json({ success: true, msg: languageMessage.msgDataFound, res });
      }
    });
  } catch (error) {
    console.log(error);
  }
};

//Admin login
const Adminlogin = async (request, response) => {
  const { email, password } = request.body;

  try {
    // Validate inputs
    if (!email) {
      return response.status(200).json({
        success: false,
        msg: languageMessage.msg_empty_param
      });
    }
    if (!password) {
      return response.status(200).json({
        success: false,
        msg: languageMessage.msg_empty_param
      });
    }

    // SQL query to fetch user information based on email
    const sqlLogin = 'SELECT email, password, user_id, active_flag FROM user_master WHERE email = ? AND delete_flag = 0';

    // Execute the SQL query
    connection.query(sqlLogin, [email], async (err, info) => {
      if (err) {
        console.error('Database error:', err);
        return response.status(200).json({
          success: false,
          msg: languageMessage.internalServerError,
          key: '5',
          error: err
        });
      }

      if (info.length == 0) {
        return response.status(200).json({ succss: false, key: 'email' });
      }

      if (info.length <= 0) {
        return response.status(200).json({ success: false, msg: languageMessage.userNotRegisterHere });
      }

      if (info[0].active_flag === 0) {
        return response.status(200).json({
          success: false,
          msg: languageMessage.accountdeactivated,
          active_status: 0
        });
      }

      // Verify password
      const hashedPassword = await hashPassword(password);
      const userLoginData = info[0];

      if (hashedPassword !== userLoginData.password) {
        return response.status(200).json({
          success: false,
          msg: languageMessage.PasswordNotCorrect,
          key: 'password'
        });
      }

      // Fetch user data using user_id
      const userData = await getUserData(userLoginData.user_id);

      if (userData) {
        const payload = { subject: info[0].email };
        const key = rs.generate();
        const token = jwt.sign(payload, key);

        return response.status(200).json({
          success: true,
          token: token,
          msg: languageMessage.loginSuccessful,
          userDataArray: userData
        });
      } else {
        return response.status(200).json({
          success: false,
          msg: languageMessage.userNotRegisterHere // or appropriate message
        });
      }
    });
  } catch (error) {
    console.error('Error in try-catch block:', error);
    return response.status(200).json({
      success: false,
      msg: languageMessage.internalServerError,
      key: '2',
      error: error
    });
  }
};

// Admin Forget Password

const AdminForgetPassword = async (request, response) => {
  const { email } = request.body;

  if (!email) {
    return response.status(200).json({
      success: false,
      msg: languageMessage.msg_empty_param
    });
  }

  console.log(email);

  try {
    const sql1 = 'SELECT user_id, email FROM user_master WHERE email = ? AND user_type = 0 AND delete_flag = 0';
    connection.query(sql1, [email], async (err, res) => {
      if (err) {
        console.error('Database error:', err);
        return response.status(200).json({
          success: false,
          msg: languageMessage.internalServerError,
          error: err
        });
      }

      if (res.length === 0) {
        return response.status(200).json({
          success: false,
          msg: languageMessage.msgUserNotFound,
          key: 'email'
        });
      }

      const userEmail = res[0].email;
      const message = 'Hello Admin';

      try {
        const mailRes = await resetmail(userEmail, message);

        if (mailRes.success === true) {
          return response.status(200).json({ success: true, msg: languageMessage.EmailSent, user_id: res[0].user_id });
        } else {
          return response.status(200).json({
            success: false,
            msg: 'Failed to send email'
          });
        }
      } catch (emailError) {
        console.error('Error sending email:', emailError);
        return response.status(200).json({
          success: false,
          msg: 'Error sending email',
          error: emailError.message
        });
      }
    });
  } catch (error) {
    console.error('Unexpected error:', error);
    return response.status(200).json({
      success: false,
      msg: 'Unexpected error',
      error: error.message
    });
  }
};

// Admin Forget New Password

const AdminForgetNewPassword = async (request, response) => {
  const { newPassword } = request.body;
  if (!newPassword) {
    return response.status(200).json({
      success: false,
      msg: languageMessage.msg_empty_param,
      key: 'password'
    });
  }
  try {
    console.log(newPassword);

    const hashedPass = await hashPassword(newPassword);
    console.log(hashedPass);

    var updatepassword = 'UPDATE user_master SET password = ?, updatetime = NOW() WHERE user_type = 0 AND delete_flag = 0';

    connection.query(updatepassword, [hashedPass], async (err) => {
      if (err) {
        return response.status(200).json({
          success: false,
          msg: languageMessage.internalServerError,
          error: err
        });
      } else {
        return response.status(200).json({
          success: true,
          msg: languageMessage.CreateNewPassword
        });
      }
    });
  } catch (err) {
    return response.status(200).json({ success: false, msg: languageMessage.internalServerError, error: err });
  }
};

//Check admin Email
const CheckAdminEmail = async (request, response) => {
  const { email } = request.body;
  if (!email) {
    return response.status(200).json({ success: false, msg: languageMessage.msg_empty_param });
  }
  try {
    var check = 'SELECT email FROM user_master WHERE email = ? AND user_type = 0 AND delete_flag = 0';
    connection.query(check, [email], async (err, res) => {
      if (err) {
        return response.status(200).json({ success: false, msg: languageMessage.internalServerError });
      }
      if (res.length <= 0) {
        return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
      }
      if (res.length > 0) {
        return response.status(200).json({ success: true, msg: languageMessage.msgDataFound, res: res[0].email });
      } else {
        return response.status(200).json({ success: false, msg: languageMessage.msgDataNotFound });
      }
    });
  } catch (error) {
    return response.status(200).json({ success: false, msg: languageMessage.internalServerError, error });
  }
};

module.exports = {
  FetchUser,
  fetchuserDate,
  FetchSubscribedUsersByDate,
  ViewUser,
  DeleteUser,
  FetchDeleteUser,
  FetchPostDetails,
  ViewPost,
  DeletePost,
  FetchCategory,
  AddCategory,
  DeleteCategory,
  UpdateCategory,
  FetchAllSubscriptions,
  AddSubscription,
  DeleteSubscription,
  EditSubscription,
  GetAllAnnouncements,
  DeleteAnnouncements,
  FetchSubscribedUsers,
  FetchReportedContent,
  EditReportedContent,
  fetchaboutcontent,
  updateContent,
  FetchContactUs,
  SendMail,
  updateStatus,
  BroadcastAll,
  Users,
  AdminData,
  UpdateAdminPassword,
  fetchSubscriptionById,
  fetchpostdetailsById,
  getAnnouncementsById,
  UpdateAdminProfile,
  UserCount,
  Adminlogin,
  AdminForgetPassword,
  AdminForgetNewPassword,
  CheckAdminEmail
};
